@@ -72,11 +72,11 @@ class App(object):
     expects.
     """
 
-    def __init__(self, menu=[]):
-        self.menu = menu
+    def __init__(self, menu=None):
+        self.menu = [] if menu is None else menu
         self.request = None
 
-    def static(self, *args, **kwargs):
+    def static(self, *args):
         return zoom.middleware.serve_response('static', *args)
 
     def process(self, *route, **data):
@@ -313,15 +313,15 @@ class AppProxy(object):
         try:
             config.read(local_config_file)
             return config.get(section, key)
-        except:
+        except BaseException:
             try:
                 config.read(shared_config_file)
                 return config.get(section, key)
-            except:
+            except BaseException:
                 try:
                     config.read(system_config_file)
                     return config.get(section, key)
-                except:
+                except BaseException:
                     if default != None:
                         return default
                     else:
@@ -453,7 +453,6 @@ def make_source_url(app_name, request):
         request.host,
         request.uri
     ])
-    original_referrer_url = request.referrer
     params = dict(
         original_url=original_url,
     )
@@ -683,22 +682,38 @@ def main_menu(request):
 
 def apps_menu(request):
     """Returns a menu of available apps"""
+
+    def calc_position(app):
+        """position of app"""
+        name = app.name
+        return names.index(name) if name in names else 9999
+
     site = request.site
-    user = zoom.get_user()
+    user = request.user
+    get = site.config.get
+
+    names = get('apps', 'apps', '')
+    names = names and [s.strip() for s in names.split(',')] or []
 
     system_apps = list(get_system_apps(request))
     main_apps = list(get_main_apps(request))
     exclude = list(a.name for a in system_apps + main_apps)
 
+    apps = [
+        app for app in sorted(site.apps, key=calc_position)
+        if app.name not in exclude and app.visible
+        and app.name in user.apps
+    ]
+
     menu_item = zoom.components.apps.AppMenuItem()
-    active_app = zoom.system.request.app.name
+    active_app = request.app.name
 
     return html.div(
         html.ul(
             menu_item.format(
                 app=app,
                 active=' active' if app.name == active_app else ''
-            ) for app in site.apps
+            ) for app in apps
             if app.name in user.apps and
             app.visible and app.name not in exclude
         ), classed='apps-menu'
@@ -734,7 +749,7 @@ def handler(request, next_handler, *rest):
         sys.path.insert(0, '.')
     response = handle(request)
     if isinstance(response, zoom.response.RedirectResponse):
-        logger.debug('app redirecting to %s' % response.headers['Location'])
+        logger.debug('app redirecting to %s', response.headers['Location'])
     else:
-        logger.debug('app responded with type %s' % type(response))
+        logger.debug('app responded with type %s', type(response))
     return response or next_handler(request, *rest)
